@@ -32,12 +32,20 @@ typedef enum {
 	SECRET_ERROR_IS_LOCKED = 2,
 	SECRET_ERROR_NO_SUCH_OBJECT = 3,
 	SECRET_ERROR_ALREADY_EXISTS = 4,
+	SECRET_ERROR_INVALID_FILE_FORMAT = 5,
 } SecretError;
 
 #define SECRET_COLLECTION_DEFAULT "default"
 
 #define SECRET_COLLECTION_SESSION "session"
 
+typedef enum {
+	SECRET_SEARCH_NONE = 0,
+	SECRET_SEARCH_ALL = 1 << 1,
+	SECRET_SEARCH_UNLOCK = 1 << 2,
+	SECRET_SEARCH_LOAD_SECRETS = 1 << 3,
+} SecretSearchFlags;
+
 G_END_DECLS
 
 #endif /* __G_SERVICE_H___ */
